@@ -9,9 +9,19 @@ def cli() -> None:
 @cli.command()
 @click.argument("dsn", type=str)
 @click.option("--schemas", "-s", type=str, default="")
-def sync(dsn: str, schemas: str) -> None:
+@click.option("--dry", "-d", is_flag=True)
+def sync(
+    dsn: str,
+    schemas: str,
+    dry: bool,
+) -> None:
     """Sync database @ [dsn] with schema."""
     from .sync import sync as do_sync
     schema = sys.stdin.read()
     include = schemas.split(" ") if schemas else None
-    do_sync(schema, dsn, include)
+    do_sync(
+        schema,
+        dsn,
+        schemas=include,
+        dry_run=dry,
+    )
