@@ -1,3 +1,4 @@
+from collections import defaultdict, OrderedDict
 import os
 from fnmatch import fnmatch
 import typing as t
@@ -31,6 +32,7 @@ class Inspection:
             i = obj["identity"]
             self.graph.add_node(i)
             self.objects[i] = obj
+
         for dep in dependencies:
             i, di = dep["identity"], dep["dependency_identity"]
 
@@ -50,8 +52,7 @@ class Inspection:
             yield self[obj_id]
 
     def __reversed__(self) -> t.Iterator[obj.DBObject]:
-        for obj_id in reversed(list(self.graph)):
-            yield self[obj_id]
+        return reversed(list(self))
 
     def ancestors(self, obj_id: str) -> t.Iterator[obj.DBObject]:
         sg = self.graph.subgraph(nx.ancestors(self.graph, obj_id))
@@ -63,31 +64,44 @@ class Inspection:
         for obj_id in nx.topological_sort(sg):
             yield self[obj_id]
 
+    def _diff(self, other: "Inspection") -> t.Iterator[str]:
+        dropped: OrderedDict[str, None] = OrderedDict()
+        ctx: dict = {"dropped": dropped}
+
+        for target in self:
+            oid = target["identity"]
+            try:
+                source = other[oid]
+            except KeyError:
+                yield from create(ctx, target)
+            else:
+
+                diffs = list(diff(ctx, source, target))
+                if not diffs:
+                    continue
+
+                for d in reversed(list(other.descendants(oid))):
+                    doid = d["identity"]
+                    if d["obj_type"] in {"view", "function"} and doid not in dropped:
+                        yield from drop(ctx, d)
+                        dropped[doid] = None
+
+                yield from diffs
+                dropped.pop(oid, None)
+
+        for doid in dropped:
+            if doid in self:
+                yield from create(ctx, self[doid])
+
+        for source in reversed(other):
+            soid = source["identity"]
+            if soid not in self and soid not in dropped:
+                yield from drop(ctx, source)
+
     def diff(self, other: "Inspection") -> t.List[str]:
         rv = []
-        ctx: dict = {
-            "source_inspect": other,
-            "target_inspect": self,
-            **self.ctx
-        }
-
-        for obj in self:
-            try:
-                other_obj = other[obj["identity"]]
-            except KeyError:
-                statement = create(ctx, obj)
-                if statement:
-                    rv.append(helpers.format_statement(statement))
-            else:
-                for s in diff(ctx, other_obj, obj):
-                    rv.append(helpers.format_statement(s))
-
-        for obj in reversed(other):
-            if obj["identity"] not in self:
-                other_obj = other[obj["identity"]]
-                statement = drop(ctx, other_obj)
-                rv.append(helpers.format_statement(statement))
-
+        for s in self._diff(other):
+            rv.append(helpers.format_statement(s))
         return rv
 
 
