@@ -13,14 +13,11 @@ SELECT
         pp.proname,
         pg_get_function_identity_arguments(pp.oid)
     ) AS signature,
-	format(
-        '%I.%I', 
-        n.nspname, 
-        format(
-            '%I(%s)',
-            pp.proname,
-            pg_get_function_identity_arguments(pp.oid)
-        )
+    format(
+        '%I.%I(%s)',
+        n.nspname,
+        pp.proname,
+        pg_get_function_identity_arguments(pp.oid)
     ) AS identity,
     pl.lanname AS language,
     pp.proisstrict AS is_strict,
